diesel_ltree provides support for Postgres’s ltree extension, including all of the operations and functions for working with hierarchial data in Postgres.
pub use crate::dsl::*;
pub use crate::functions::*;
pub use crate::values::*;