pub trait LqueryArrayExtensions: Expression<SqlType = Array<Lquery>> + Sized {
// Provided methods
fn any_matches<T: AsExpression<Ltree>>(
self,
other: T,
) -> MatchesAny<Self, T::Expression> { ... }
fn any_matches_any<T: AsExpression<Array<Ltree>>>(
self,
other: T,
) -> MatchesAny<Self, T::Expression> { ... }
}Expand description
Adds Lquery-specific extensions to arrays of Lquery expressions.
Provided Methods
Sourcefn any_matches<T: AsExpression<Ltree>>(
self,
other: T,
) -> MatchesAny<Self, T::Expression>
fn any_matches<T: AsExpression<Ltree>>( self, other: T, ) -> MatchesAny<Self, T::Expression>
Checks if any Lquery expression in the array matches the specified Ltree expression.
Sourcefn any_matches_any<T: AsExpression<Array<Ltree>>>(
self,
other: T,
) -> MatchesAny<Self, T::Expression>
fn any_matches_any<T: AsExpression<Array<Ltree>>>( self, other: T, ) -> MatchesAny<Self, T::Expression>
Checks if any Lquery expression in the array matches any Ltree expression in the given array.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.